%MATLAB script for DieCAST ocean model output
%PARTICULARLY FOR 'THREE DIMENSIONAL DENSITY CURRENT EXAMPLES-XYPLOTS'
%RUNNING THE SCRIPT DIRECTLY WILL OUTPUT THE BOUDARY LAYER VELOCITY FIELD
%AND TEMPERATURE ANOMALY at THE MIDDLE and THE END OF THE SIMULATION
%OUTPUT THE ANIMATION IF 'make_animation'=1
%THIS SCRIPT CAN BE MODIFIED  IN ORDER TO INCLUDE INSTANTENOUS FIELDS
%READ THE FOLLOWING COMMENTS BEFORE RUNNING THE SCRIPT
%READING DATA FROM XYPLOTS/DATA
%NEED TO SPECIFY THE DATA LOCATION ("DIR_LOCATION")
%                WORKING  PLATFORM (IEEE='l','b','n')
%                MACHINE
%NOTE: IF 64 BITS MAHCINE IS USED, MAYBE YOU NEED TO RESPECIFY
%      "INTSIZE4,INTSIZE2,REALSIZE" IN matlab/read_data_ile.m
%OPTIONS:
%"stp":SKIPPING in VECTOR PLOTS (e.g. 2 every 2nd grid is shown)
%"make_animation": MAKE ANIMATION
%OUTPUT from read_data_den_XY FUNCTION:
%'MOV':output data time for animation (e.g. MOV=[0.25 0.5 0.75 1]
%      means output at day 0.25, 0.5, 0.75, 1
%'U_B','V_B','T_B': output bottom boundary layer velocity and temperature
%'U_END','V_END','T_END','P_END': output final velocity,
%                                 temperature and pressure
%AUTHORS BY YH-HENG TSENG 08/2004
%THESE SCRIPTS ARE PREPARED FOR GENERAL PURPOSE
%PLEASE REPORT ANY PROBLEMS/QUESTIONS TO yhtseng@stanfordalumni.org
clear;
IEEE='n';%'n': native;'b': big-endian;'l': little-endian;
DIR_LOCATION='../DENSITY_CURRENT/110x40x22';
make_animation=0;
stp=2;
addpath('matlab/')
VOR_NAME='vorticity (per week)          ';    %(1)FN='s'
SSH_P_NAME='pressure-equivalent f.s.a.(cm)';  %(2)FN='P'
LON_U_NAME='longitudinal velocity (cm/sec)';  %(3)FN='u'
LAT_V_NAME='latitudinal velocity (cm/sec) ';  %(4)FN='v'
DIR_FILE=[DIR_LOCATION '/XYPLOTS/DATA'];
[MOV,U_B,V_B,T_B,U_END,V_END,T_END,P_END,I2,J2,K2,IN,ODX,ODY,ODZ,Z]=read_data_den_XY(DIR_FILE,IEEE);
IN1=IN(2:end-1,2:end-1,1);
DX=1./ODX(2:end-1)*1E-5;DY=1./ODY(2:end-1)*1E-5;DZ=1./ODZ(2:end-1)*1E-5;
[X,Y]=ndgrid(-DX(1)*(I2-1):DX(1):0,-DY(1)*(J2-1):DY(1):0);
ZMID=Z(2:2:end);IND_D=sum(IN(2:end-1,2:end-1,:),3);
DEPTH=ZMID(IND_D);
CONT_T=[0 0.3 0.5 1:5];

CONT_VOR=[-80:10:-10 10:10:80];
T_B(T_B<0)=0;
TOTAL_MOV=length(MOV);
fig=0;
if(make_animation==1)
fig=fig+1;
figure(fig)
for t=1:TOTAL_MOV
clf
subplot(3,1,2)
TEMP_S=T_B(:,:,t);TEMP_U=U_B(:,:,t);TEMP_V=V_B(:,:,t);
contourf(X,Y,TEMP_S,CONT_T);
colorbar
axis([-10 0 -1.5 0]*1E2)
hold on
quiver(X(1:stp:end,1:stp:end),Y(1:stp:end,1:stp:end),TEMP_U(1:stp:end,1:stp:end),TEMP_V(1:stp:end,1:stp:end),'k')
hold off
set(gca,'fontsize',14)
title(['Day=' num2str(MOV(t))])
xlabel('X(km)'),ylabel('Y(km)')
pause(0.2)
end
end

fig=fig+1;
figure(fig)
clf
subplot(2,1,1)
t=TOTAL_MOV/2;
TEMP_S=T_B(:,:,t);TEMP_U=U_B(:,:,t);TEMP_V=V_B(:,:,t);
contourf(X,Y,TEMP_S,CONT_T);
%caxis([9 14]);
colorbar
hold on
quiver(X(1:stp:end,1:stp:end),Y(1:stp:end,1:stp:end),TEMP_U(1:stp:end,1:stp:end),TEMP_V(1:stp:end,1:stp:end),2,'k')
hold off
axis([-10 0 -1.5 0]*1E2)
set(gca,'fontsize',14)
colormap default
CMAP=colormap;colormap(CMAP(11:end,:));
%HCB=colorbar;PO=get(HCB,'position');
%set(HCB,'position',[0.75 PO(2) PO(3) PO(4)],'fontsize',16);
xlabel('(c) X(km)')%,ylabel('Y(m)')
title(['day' num2str(MOV(t))])

subplot(2,1,2)
t=TOTAL_MOV;
TEMP_S=T_B(:,:,t);TEMP_U=U_B(:,:,t);TEMP_V=V_B(:,:,t);
contourf(X,Y,TEMP_S,CONT_T);
%caxis([9 14]);
colorbar
hold on
quiver(X(1:stp:end,1:stp:end),Y(1:stp:end,1:stp:end),TEMP_U(1:stp:end,1:stp:end),TEMP_V(1:stp:end,1:stp:end),2,'k')
hold off
axis([-10 0 -1.5 0]*1E2)
set(gca,'fontsize',14)
colormap default
CMAP=colormap;colormap(CMAP(11:end,:));
xlabel('(c) X(km)')%,ylabel('Y(m)')
title(['day' num2str(MOV(t))])

