%MATLAB script for DieCAST ocean model output
%PARTICULARLY FOR 'THREE DIMENSIONAL DENSITY CURRENT EXAMPLES-XZPLOTS'
%RUNNING THE SCRIPT DIRECTLY WILL OUTPUT THE VERTICAL PROFILE OF
%TEMPERATURE ALONG (Y="KLAYERA",WHICH IS THE SECTION MOST CLOSE TO THE COAST)
%AT THREE DIFFERENT TIME (SPECIFY IN "TIME_PLOT")
%OUTPUT THE ANIMATION IF 'make_animation'=1
%THIS SCRIPT CAN BE MODIFIED IN ORDER TO INCLUDE OTHER FIELDS
%READ THE FOLLOWING COMMENTS BEFORE RUNNING THE SCRIPT
%READING DATA FROM XYPLOTS/DATA
%NEED TO SPECIFY THE DATA LOCATION ("DIR_LOCATION")
%                WORKING  PLATFORM (IEEE='l','b','n')
%                MACHINE
%NOTE: IF 64 BITS MAHCINE IS USED, MAYBE YOU NEED TO RESPECIFY
%      "INTSIZE4,INTSIZE2,REALSIZE" IN matlab/read_data_ile.m
%OPTIONS:
%"TIME_PLOT": PLOTTING TIME
%"stp":SKIPPING in VECTOR PLOTS (e.g. 2 every 2nd grid is shown)
%"make_animation": MAKE ANIMATION
%OUTPUT from read_data_den_XY FUNCTION:
%'TIME':output data time for animation (e.g. MOV=[0.25 0.5 0.75 1]
%      means output at day 0.25, 0.5, 0.75, 1
%T_series is the time series data for temperature along y=("KLAYERA")
%'U','V','W','T','S': output final velocity, temperature and pressure
%                     field along vertical layer ("KLAYERB")
%AUTHORS BY YH-HENG TSENG 08/2004
%THESE SCRIPTS ARE PREPARED FOR GENERAL PURPOSE
%PLEASE REPORT ANY PROBLEMS/QUESTIONS TO yhtseng@stanfordalumni.org
clear;
IEEE='l';%'n': native;'b': big-endian;'l': little-endian;
DIR_LOCATION='../DENSITY_CURRENT/110x40x22';
stp=2;
make_animation=0;
TIME_PLOT=[5 15 30];
addpath('matlab/')
T_NAME='Temperature (degree)        ';        %(1)FN='T'
LON_U_NAME='longitudinal velocity (cm/sec)';  %(3)FN='u'
LAT_V_NAME='latitudinal velocity (cm/sec) ';  %(4)FN='v'
DIR_FILE=[DIR_LOCATION '/XZPLOTS/DATA'];
[T_series,U,V,W,S,T,I2,J2,K2,IN,ODX,ODY,ODZ,Z,KLAYERA,KLAYERB,TIME]=read_data_den_XZ(DIR_FILE,IEEE);

INA=IN(2:end-1,KLAYERA,:);
INB=IN(2:end-1,KLAYERB,:);
DX=1./ODX(2:end-1)*1E-5;DY=1./ODY(2:end-1)*1E-5;DZ=1./ODZ(2:end-1)*1E-2;
[X,Y]=ndgrid(-DX(1)*(I2-1):DX(1):0,0:-DZ(1):-DZ(1)*K2);
CONT_T=[ceil(min(min(min(T_series)))):1:15];
%cont_VOR=[ceil(min(min(min(VOR)))/10)*10:5:-10 10:5:floor(min(min(min(VOR)))/10)*10];
%CONT_VOR=[-80:20:-20 20:20:80];
CONT_VOR=[-80:10:-10 10:10:80];

TOTAL_TIME=length(TIME);
FIG=0;
if(make_animation==1)
FIG=FIG+1;
figure(FIG)
clf
for II=1:TOTAL_TIME
TEMP_S=T_series(:,:,II).*squeeze(INA);
[C,H]=contourf(X,Y,TEMP_S,CONT_T);
axis image
axis([-10 0 -4 0]*1E2)
set(gca,'fontsize',14)
title(['Day= ' num2str(TIME(II))])
xlabel('X(km)'),ylabel('Depth(m)')
caxis([9 15])
[H]=colorbar('h');
set(H,'fontsize',14)
%pause
end
end


FIG=FIG+1;
figure(FIG)
clf
subplot(3,1,1)
II=TIME_PLOT(1)*4;
TEMP_S=T_series(:,:,II).*squeeze(INA);
[C,H]=contour(X,Y,TEMP_S,CONT_T);
axis([-10 0 -5 0]*1E2)
clabel(C,H,CONT_T(1:2:end))
set(gca,'fontsize',12)
title(['Day= ' num2str(TIME(II))])
subplot(3,1,2)
II=TIME_PLOT(2)*4;
TEMP_S=T_series(:,:,II).*squeeze(INA);
[C,H]=contour(X,Y,TEMP_S,CONT_T);
axis([-10 0 -5 0]*1E2)
clabel(C,H,CONT_T(1:2:end))
set(gca,'fontsize',12)
title(['Day= ' num2str(TIME(II))]),ylabel('depth (m)')
subplot(3,1,3)
II=TIME_PLOT(3)*4;
TEMP_S=T_series(:,:,II).*squeeze(INA);
[C,H]=contour(X,Y,TEMP_S,CONT_T);
axis([-10 0 -5 0]*1E2)
clabel(C,H,CONT_T(1:2:end))
set(gca,'fontsize',12)
title(['Day= ' num2str(TIME(II))])
xlabel('X(km)')
