%MATLAB script for DieCAST ocean model output
%PARTICULARLY FOR 'THREE DIMENSIONAL DENSITY CURRENT EXAMPLES-YZPLOTS'
%RUNNING THE SCRIPT DIRECTLY WILL OUTPUT THE VERTICAL PROFILE OF
%TEMPERATURE ANOMALY AVERAGING BETWEEN THE CENTER OF THE NORTHERN INFLOW
%CURRENT AND THE WESTERN OUTFLOW BOUNDARY
%AND TEMPERATURE ALONG X="I" POSITION
%THIS SCRIPT CAN BE MODIFIED IN ORDER TO INCLUDE OTHER FIELDS
%READ THE FOLLOWING COMMENTS BEFORE RUNNING THE SCRIPT
%READING DATA FROM XYPLOTS/DATA
%NEED TO SPECIFY THE DATA LOCATION ("DIR_LOCATION")
%                WORKING  PLATFORM (IEEE='l','b','n')
%                MACHINE
%NOTE: IF 64 BITS MAHCINE IS USED, MAYBE YOU NEED TO RESPECIFY
%      "INTSIZE4,INTSIZE2,REALSIZE" IN matlab/read_data_ile.m
%OPTIONS:
%"stp":SKIPPING in VECTOR PLOTS (e.g. 2 every 2nd grid is shown)
%OUTPUT from read_data_den_XY FUNCTION:
%'U','V','W','T','S': output final vertical section of
%                     velocity, temperature and pressure
%                     field along vertical layer ("KLAYERB")
%'T_D' output temperature anomaly in the final time (along x="KLAYERA")
%AUTHORS BY YH-HENG TSENG 08/2004
%THESE SCRIPTS ARE PREPARED FOR GENERAL PURPOSE
%PLEASE REPORT ANY PROBLEMS/QUESTIONS TO yhtseng@stanfordalumni.org
clear;
IEEE='l';%'n': native;'b': big-endian;'l': little-endian;
addpath('matlab/')
T_NAME='Temperature (degree)        ';        %(1)FN='T'
LON_U_NAME='longitudinal velocity (cm/sec)';  %(3)FN='u'
LAT_V_NAME='latitudinal velocity (cm/sec) ';  %(4)FN='v'
DIR_LOCATION='../DENSITY_CURRENT/110x40x22';
DIR_FILE=[DIR_LOCATION '/YZPLOTS/DATA'];
[T_D,U,V,T,I2,J2,K2,IN,ODX,ODY,ODZ,Z,KLAYERA,KLAYERB]=read_data_den_YZ(DIR_FILE,IEEE);
IN1=squeeze(IN(5,2:end-1,:));
INM=IN1;
INM(IN1==1)=NaN;
DX=1./ODX(2:end-1)*1E-5;DY=1./ODY(2:end-1)*1E-5;DZ=1./ODZ(2:end-1)*1E-2;
[X,Y]=ndgrid(-DY(1)*(J2-1):DY(1):0,0:-DZ(1):-DZ(1)*K2);
I=16;
stp=2;
CONT_T=[0.5:0.5:5];
CONT_VOR=[-80:10:-10 10:10:80];

II=length(KLAYERA)-2;
figure(1)
clf
TEMP_S=T_D(:,:,II).*IN1;
[C,H]=contour(X,Y,TEMP_S,CONT_T);
clabel(C,H,CONT_T(1:2:end),'fontsize',14,'labelspacing',720)
hold on
pcolor(X,Y,INM)
shading flat
hold off
xlim([-250 0])
set(gca,'fontsize',14)
xlabel('Y(Km)'),ylabel('Depth(m)')

II=length(KLAYERB)
figure(2)
clf
CONT_T=9:0.5:15;
TEMP_S=T(:,:,I).*IN1;TEMP_U=U(:,:,I).*IN1;TEMP_V=V(:,:,I).*IN1;
[C,H]=contour(X,Y,TEMP_S,CONT_T);
clabel(C,H,CONT_T(1:2:end),'fontsize',14,'labelspacing',800)
hold on
pcolor(X,Y,INM)
shading flat
hold off
xlim([-250 0])
set(gca,'fontsize',14)
xlabel('Y(Km)'),ylabel('Depth(m)')
