%MATLAB script for DieCAST ocean model output
%PARTICULARLY FOR 'ISLAND WAKE EXAMPLES'
%READ THE FOLLOWING COMMENTS BEFORE RUNNING THE SCRIPT
%READING DATA FROM XYPLOTS/DATA
%NEED TO SPECIFY THE CODE LOCATION ("DIR_LOCATION")
%                WORKING  PLATFORM (IEEE='l','b','n')
%                MACHINE
%NOTE: IF 64 BITS MAHCINE IS USED, MAYBE YOU NEED TO RESPECIFY
%      "INTSIZE4,INTSIZE2,REALSIZE" IN matlab/read_data_ile.m
%OPTIONS:
%"TIME_PLOT":YOU CAN CHANGE TIME_PLOT TO PLOT RESULTS FROM DIFFERENT
%            TIME STEPS (e.g. [30:90:120] plots day 30 and 120)
%"stp":SKIPPING in VECTOR PLOTS (e.g. 2 every 2nd grid is shown)
%AUTHORS BY YH-HENG TSENG 08/2004
%THESE SCRIPTS ARE PREPARED FOR GENERAL PURPOSE
%PLEASE REPORT ANY PROBLEMS TO yhtseng@stanfordalumni.org
%
clear;
IEEE='n';%'n': native;'b': big-endian;'l': little-endian;
DIR_LOCATION='../ISLAND/80x80/';
TIME_PLOT=[30:90:120];TOTAL_TIME=length(TIME_PLOT);
stp=2;
VOR_NAME='vorticity (per week)          ';    %(1)FN='s'
SSH_P_NAME='pressure-equivalent f.s.a.(cm)';  %(2)FN='P'
LON_U_NAME='longitudinal velocity (cm/sec)';  %(3)FN='u'
LAT_V_NAME='latitudinal velocity (cm/sec) ';  %(4)FN='v'
addpath('matlab/')
DIR_FILE=[DIR_LOCATION '/XYPLOTS/DATA'];
[VOR,P,U,V,I2,J2,K2,IN,ODX,ODY,ODZ,Z]=read_data_ile(DIR_FILE,TIME_PLOT,IEEE);
IN1=IN(2:end-1,2:end-1,1);
DX=1/ODX*1E-5;DY=1/ODY*1E-5;DZ=1/ODZ*1E-5;
[X,Y]=ndgrid(-DX*(I2/2):DX:DX*(I2/2-1),0:DY:DY*(J2-1));

fig=0;
for t=1:TOTAL_TIME

if(TIME_PLOT(t)<10)
RUNS=['00' num2str(TIME_PLOT(t))];
elseif(TIME_PLOT(t)<100)
RUNS=['0' num2str(TIME_PLOT(t))];
else
RUNS=num2str(TIME_PLOT(t));
end

fig=fig+1;
figure(fig)
clf
TEMP_S=IN1;TEMP_U=U(:,:,t);TEMP_V=V(:,:,t);
contour(X,Y,TEMP_S,1,'k')
hold on
quiver(X(1:stp:end,1:stp:end),Y(1:stp:end,1:stp:end),TEMP_U(1:stp:end,1:stp:end),TEMP_V(1:stp:end,1:stp:end),3)
hold off
axis image
axis([-1.5 1.5 0 4]*1E2)
set(gca,'fontsize',16)
xlabel('X(m)'),ylabel('Y(m)')
title(['Velocity vector at day=' num2str(TIME_PLOT(t))])
fig=fig+1;
figure(fig)
clf
MAXVOR=100;MINVOR=-MAXVOR;
DISPLAY=[MINVOR:5:-10 10:5:MAXVOR];
TEMP_S=VOR(:,:,t);
TEMP_S(IN1==0)=NaN;
contourf(X,Y,TEMP_S,DISPLAY);
axis image
axis([-1.5 1.5 0 4]*1E2)
set(gca,'fontsize',16)
HCB=colorbar;PO=get(HCB,'position');
set(HCB,'position',[0.75 PO(2) PO(3) PO(4)],'fontsize',16);
xlabel('X(m)'),ylabel('Y(m)')
title(['Vorticity at day=' num2str(TIME_PLOT(t))])
end
